<?php

namespace Drupal\live_notifications\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Session\AccountProxyInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\JsonResponse;
use Symfony\Component\HttpFoundation\Request;
use Drupal\Core\State\StateInterface;

/**
 * Controller for notification REST endpoints.
 */
class NotificationController extends ControllerBase {

  /**
   * The current user.
   *
   * @var \Drupal\Core\Session\AccountProxyInterface
   */
  protected $currentUser;

  /**
   * The state service.
   *
   * @var \Drupal\Core\State\StateInterface
   */
  protected $state;

  /**
   * Constructs a new NotificationController.
   *
   * @param \Drupal\Core\Session\AccountProxyInterface $current_user
   *   The current user.
   * @param \Drupal\Core\State\StateInterface $state
   *   The state service.
   */
  public function __construct(AccountProxyInterface $current_user, StateInterface $state) {
    $this->currentUser = $current_user;
    $this->state = $state;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('current_user'),
      $container->get('state')
    );
  }

  /**
   * Mark notification as read.
   *
   * @param \Symfony\Component\HttpFoundation\Request $request
   *   The request.
   *
   * @return \Symfony\Component\HttpFoundation\JsonResponse
   *   The JSON response.
   */
  public function markAsRead(Request $request) {
    $content = json_decode($request->getContent(), TRUE);
    
    if (!isset($content['notification_id'])) {
      return new JsonResponse(['status' => 'error', 'message' => 'Missing notification_id'], 400);
    }
    
    // In a real implementation, you would update the notification status in a database
    // For now, we'll return a success response
    return new JsonResponse(['status' => 'success']);
  }

  /**
   * Clear all notifications.
   *
   * @return \Symfony\Component\HttpFoundation\JsonResponse
   *   The JSON response.
   */
  public function clearAll() {
    // In a real implementation, you would clear all notifications for the current user
    // For now, we'll return a success response
    return new JsonResponse(['status' => 'success']);
  }
}