<?php

namespace Drupal\live_notifications\Plugin\Block;

use Drupal\Core\Block\BlockBase;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\Core\Config\ConfigFactoryInterface;

/**
 * Provides a 'Live Notifications' block.
 *
 * @Block(
 *   id = "live_notifications_block",
 *   admin_label = @Translation("Live Notifications"),
 * )
 */
class LiveNotificationsBlock extends BlockBase implements ContainerFactoryPluginInterface {

  /**
   * The config factory.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $configFactory;

  /**
   * Constructs a new LiveNotificationsBlock instance.
   *
   * @param array $configuration
   *   The plugin configuration.
   * @param string $plugin_id
   *   The plugin_id for the plugin instance.
   * @param mixed $plugin_definition
   *   The plugin implementation definition.
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The config factory.
   */
  public function __construct(array $configuration, $plugin_id, $plugin_definition, ConfigFactoryInterface $config_factory) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->configFactory = $config_factory;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('config.factory')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function build() {
    $config = $this->configFactory->get('live_notifications.settings');

    $build = [
      '#theme' => 'block',
      '#attributes' => [
        'id' => 'live-notifications-container',
      ],
      '#attached' => [
        'library' => [
          'live_notifications/live_notifications',
        ],
        'drupalSettings' => [
          'liveNotifications' => [
            'pusherKey' => $config->get('pusher_app_key'),
            'pusherCluster' => $config->get('pusher_cluster'),
          ],
        ],
      ],
    ];

    return $build;
  }

}